@@ -5,7 +5,7 @@ from django.conf import settings as settings
 import pytz
 
 
-logger = logging.getLogger("thermostat")
+logger = logging.getLogger("thermostat.rules.mappings")
 logger.setLevel(settings.LOG_LEVEL)
 
 
@@ -79,7 +79,7 @@ def is_weekend(mo=None):
 def is_at_night(mo=None):
     try:
         a = Location()
-        a.timezone = dsettings.TIME_ZONE
+        a.timezone = settings.TIME_ZONE
         tz = pytz.timezone(a.timezone)
         #Tue, 22 Jul 2008 08:17:41 +0200
         #Sun, 26 Jan 2014 17:39:49 +01:00
@@ -97,10 +97,10 @@ def is_at_night(mo=None):
         logger.debug("Passed %s sunset more than %s minutes" % (passed_sunset, settings.MINUTES_AFTER_SUNSET_FOR_DAY))
 
         if not passed_sunrise or passed_sunset:
-            logger.debug("Is not at night")
+            logger.debug("Is at night")
             return 1
         if passed_sunrise and not passed_sunset:
-            logger.debug("Is at night")
+            logger.debug("Is not at night")
             return 0
     except Exception as ex:
         logger.error(ex)
