@@ -6,7 +6,7 @@ from django.core.urlresolvers import reverse
 from time import strftime, localtime, mktime, strptime
 import os, logging, simplejson
 
-logger = logging.getLogger("thermostat")
+logger = logging.getLogger("thermostat.rules.mappings")
 logger.setLevel(settings.LOG_LEVEL)
 
 
@@ -80,7 +80,7 @@ def tuned_temperature(mo=None):
         ctxt = Context.objects.get()
 
         t = float(ctxt.tuned_temperature) + settings.HEATER_MARGIN \
-            if ctxt.flame elsectxt.tuned_temperature
+            if ctxt.flame else ctxt.tuned_temperature
         logger.debug("Tunned temp: %s" % t)
         return t
     except Exception as et:
